Modulatory Mechanisms
=====================

.. _ModulatoryMechanism_Subtypes:

.. toctree::
   :maxdepth: 1

   Control Mechanisms <ControlMechanism>
   Learning Mechanisms <LearningMechanism>

.. automodule:: psyneulink.core.components.mechanisms.modulatory.modulatorymechanism
   :members:
   :exclude-members: Linear, random, Parameters

